@@ -60,12 +60,12 @@ class TabularFormatter(FormatterBase):
             df = pd.DataFrame.from_records(records)
             if parameters.format == OutputFormat.xlsx:
                 bio = io.BytesIO()
-                df.to_excel(bio)
+                df.to_excel(bio, index=False)
                 resp = Response(content=bio.getvalue(),
                                 media_type="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet")
             elif parameters.format == OutputFormat.csv:
                 sio = io.StringIO()
-                df.to_csv(sio)
+                df.to_csv(sio, index=False)
                 resp = Response(content=sio.getvalue(),
                                 media_type="text/csv")
             return resp
